@@ -129,6 +129,9 @@ def get_course_by_name(name, courses):
 def update(config):
     """Update the MWC work directory"""
     settings = read_settings(config)
+    if not settings:
+        click.echo(error(f"Please run mwc setup first."))
+        return
     curr = get_curriculum(settings)
     course = [c for c in curr['courses'] if c['name'] == settings['course']][0]
     backend = course['git_backend']
